OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoris",
    "Add a Bookmark" : "Ajouter un favori",
    "Add folder" : "Ajouter un dossier",
    "Select" : "Sélectionner",
    "Deselect" : "Désélectionner",
    "Details" : "Propriétés",
    "Delete" : "Supprimer",
    "Saved" : "Sauvegardé",
    "Date added" : "Date d'ajout",
    "Link" : "Lien",
    "Tags" : "Étiquettes",
    "Description" : "Description",
    "No bookmarks here." : "Pas de favoris ici.",
    "Favorites" : "Favoris",
    "Settings" : "Paramètres",
    "Bookmarklet" : "Favelets",
    "Add to {instanceName} " : "Ajouter à {instanceName}",
    "Recently added" : "Ajoutés récemment",
    "Most visited" : "Les plus visités",
    "View mode" : "Mode d'affichage",
    "List view" : "Affichage liste",
    "RSS Feed" : "Flux RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Supprimer de manière définitive tous les favoris de votre compte. Il n'y a aucun moyen de revenir en arrière !",
    "Delete all bookmarks" : "Supprimer tous les favoris",
    "Open details" : "Ouvrir les détails",
    "An error occurred while trying to save the bookmark." : "Une erreur est survenue lors de la sauvegarde du marque-page.",
    "Error" : "Erreur",
    "Uncategorized" : "Non catégorisé",
    "Error parsing the import result" : "Erreur lors de l'analyse du résultat d'import",
    "Import completed successfully." : "Importation terminée avec succès.",
    "Do you really want to delete all your bookmarks?" : "Voulez-vous réellement supprimer tous vos favoris ?",
    "Set tags" : "Choisir des étiquettes",
    "Not allowed to access folder to import into" : "Non autorisé à accéder au dossier dans lequel importer",
    "Failed to import one bookmark, because: " : "Échec lors de l\\'importation d'un favori. Raison: ",
    "No file provided for import" : "Aucun fichier à importer.",
    "Unsupported file type for import" : "Type de fichier non pris en charge",
    "A Bookmark manager for Nextcloud" : "Un gestionnaire de favoris pour Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Cette application vous permet d'enregistrer et d'organiser vos sites favoris du web en un seul lieu, et vous permettre de les synchroniser avec vos différents appareils et navigateurs.\nConsultez la liste des clients tiers ici : https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Ajouter un favori",
    "This URL is already bookmarked! Overwrite?" : "Cette URL est déjà dans les favoris ! Remplacer ?",
    "The title of the page" : "Titre de la page",
    "The address of the page" : "Adresse de la page",
    "Description of the page" : "Description de la page",
    "Save" : "Enregistrer",
    "Previews" : "Prévisualisations",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Pour afficher de vrais captures d'écran de vos sites internet mis en favoris, Favoris peux utiliser un service tiers pour les générer.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Vous pouvez soit vous inscrire gratuitement sur <a href=\"http://screeenly.com\">screenly.com</a> ou <a href=\"https://github.com/stefanzweifel/screeenly\">configurer votre propre serveur</a>.",
    "Screeenly API URL" : "URL API Screenly",
    "Screeenly API key" : "Clé API Screenly",
    "Bookmarks feed" : "Flux de suivi"
},
"nplurals=2; plural=(n > 1);");
